package com.vendor.burn.serial.workers;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import com.vendor.burn.Messages;
import com.vendor.burn.jna.LibBootromByJNA;
import com.vendor.burn.model.LocalConfig;
import com.vendor.burn.model.PartitionItem;
import com.vendor.burn.model.TransferWay;
import com.vendor.burn.model.config.BurnConfig;
import com.vendor.burn.model.define.IBurner;
import com.vendor.burn.model.devices.IDeviceSetting;
import com.vendor.burn.model.devices.IFrameSetting;
import com.vendor.burn.model.devices.burners.FastbootBurner;
import com.vendor.burn.model.devices.unknown.UnknownDevice;
import com.vendor.burn.serial.workers.AbstractBurnerWorker;
import com.vendor.burn.serial.workers.CallLibBootromWorker;
import com.vendor.burn.utilitily.FileUtils;
import com.vendor.burn.views.FastbootView;
import java.util.List;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.SubMonitor;

public class OneImageBurnerWorker extends AbstractBurnerWorker {
  private static final int UIMONITOR_100 = 100;
  
  public OneImageBurnerWorker(IFrameSetting frameSetting, FastbootBurner oneImageBurner) {
    super(frameSetting);
    this.burner = (IBurner)oneImageBurner;
  }
  
  public void burn(IProgressMonitor monitor, List<PartitionItem> parts, boolean isHasAllinone) {
    TransferWay transferWay = this.burner.getBurnContext().getTransferWay();
    LocalConfig localConfig = this.burner.getBurnContext().getLocalConfig();
    if (localConfig.getLoaderPath().isEmpty() && !isHasAllinone) {
      infoln("* " + Messages.pleaseImportLoader + "        *");
      return;
    } 
    boolean isAllinoneLoader = false;
    if (isHasAllinone && localConfig.isDefaultAllinoneLoader()) {
      isAllinoneLoader = true;
    } else if (isHasAllinone && !localConfig.isDefaultAllinoneLoader() && localConfig.getLoaderPath().isEmpty()) {
      isAllinoneLoader = true;
    } 
    if (transferWay == TransferWay.Serial && 
      FastbootView.isChipBranchSeries5ByUI())
      burnOneImage(monitor, parts, isAllinoneLoader); 
  }
  
  private void burnOneImage(IProgressMonitor uimonitor, List<PartitionItem> parts, boolean isAllinoneLoader) {
    SubMonitor subProgressMonitor = SubMonitor.convert(uimonitor, "", 100);
    subProgressMonitor.beginTask("", 100);
    subProgressMonitor.setTaskName("Downloading Boot");
    LocalConfig localConfig = this.burner.getBurnContext().getLocalConfig();
    new CallLibBootromWorker(this.frameSetting, this.burner, subProgressMonitor);
    LibBootromByJNA.instance.RegisterPrint(CallLibBootromWorker.callback);
    LibBootromByJNA.instance.RegisterCancel(CallLibBootromWorker.callbackCancel);
    CallLibBootromWorker.setChipType(FastbootView.getDepartmentNumber(this.burner), 
        FastbootView.getChipType(this.burner));
    if (!openSerial())
      return; 
    long comFd = CallLibBootromWorker.getComFd();
    subProgressMonitor.worked(10);
    if (!burnLoader(isAllinoneLoader, comFd, localConfig)) {
      printErrorLog("upgrade");
      return;
    } 
    receivedln("Boot Download Successful");
    for (PartitionItem item : parts) {
      if (!item.isChecked())
        continue; 
      long address = item.getStart();
      if (item.isInAllinone()) {
        CallLibBootromWorker.setBurnFileIndex(item.getAllinoneFileIndex());
        if (!CallLibBootromWorker.downloadEX(comFd, null, 0L, address)) {
          printErrorLog("upgrade");
          receivedln("Burn Flash Fail");
          return;
        } 
        continue;
      } 
      byte[] data = FileUtils.readAllBytes(item.getName());
      if (!CallLibBootromWorker.downloadEX(comFd, data, data.length, address)) {
        printErrorLog("upgrade");
        receivedln("Burn Flash Fail");
        return;
      } 
    } 
    if (!CallLibBootromWorker.sendReset(comFd)) {
      printErrorLog("reset");
      return;
    } 
    subProgressMonitor.worked(100);
    subProgressMonitor.done();
    receivedln("Burn Successful");
  }
  
  private boolean openSerial() {
    CallLibBootromWorker.setTypeFrameTimeout(BurnConfig.getBeforeBurningDelayTime());
    deleteContent(errorRecvBuffer);
    String portName = this.burner.getBurnContext().getLocalConfig().getComPort();
    if (!openSerialComm(this.burner.getBurnContext().getTransferWay())) {
      printBurnLog(false, portName);
      return false;
    } 
    printBurnLog(true, portName);
    return true;
  }
  
  private boolean burnLoader(boolean isAllinoneLoader, long comFd, LocalConfig localConfig) {
    if (isAllinoneLoader) {
      CallLibBootromWorker.setBurnFileIndex(0);
      if (!CallLibBootromWorker.bootromBootDownloadEX(comFd, null, 0L, 0L)) {
        receivedln("Boot Download Fail");
        return false;
      } 
    } else {
      byte[] data = FileUtils.readAllBytes(localConfig.getLoaderPath());
      long address = 0L;
      UnknownDevice setting = getUnkownDevice();
      if (setting != null)
        address = setting.getLoaderBurnAdderss(); 
      if (!CallLibBootromWorker.bootromBootDownloadEX(comFd, data, data.length, address)) {
        receivedln("Burn Loader Fail");
        return false;
      } 
    } 
    return true;
  }
  
  private UnknownDevice getUnkownDevice() {
    UnknownDevice device = null;
    IDeviceSetting setting = this.burner.getBurnContext().getDeviceSetting();
    if (setting instanceof UnknownDevice)
      device = (UnknownDevice)setting; 
    return device;
  }
  
  public boolean upload(IProgressMonitor monitor, long length, long address, String path) {
    SubMonitor subProgressMonitor = SubMonitor.convert(monitor, "", 100);
    subProgressMonitor.beginTask("", 100);
    subProgressMonitor.setTaskName("Downloading Boot");
    new CallLibBootromWorker(this.frameSetting, this.burner, subProgressMonitor);
    LibBootromByJNA.instance.RegisterPrint(CallLibBootromWorker.callback);
    LibBootromByJNA.instance.RegisterCancel(CallLibBootromWorker.callbackCancel);
    CallLibBootromWorker.setChipType(FastbootView.getDepartmentNumber(this.burner), 
        FastbootView.getChipType(this.burner));
    if (!openSerial())
      return false; 
    long comFd = CallLibBootromWorker.getComFd();
    subProgressMonitor.worked(10);
    LocalConfig localConfig = this.burner.getBurnContext().getLocalConfig();
    byte[] data = FileUtils.readAllBytes(localConfig.getLoaderPath());
    long loaderAddress = 0L;
    UnknownDevice setting = getUnkownDevice();
    if (setting != null)
      loaderAddress = setting.getLoaderBurnAdderss(); 
    if (!CallLibBootromWorker.bootromBootDownloadEX(comFd, data, data.length, loaderAddress)) {
      receivedln("Burn Loader Fail");
      printErrorLog("upload");
      return false;
    } 
    receivedln("Boot Download Successful");
    if (!CallLibBootromWorker.uploadFileEx(comFd, address, length, path)) {
      receivedln("Upload File Fail");
      printErrorLog("upload");
      return false;
    } 
    subProgressMonitor.worked(100);
    receivedln("Upload File Successful");
    subProgressMonitor.done();
    return true;
  }
  
  public void reset(IProgressMonitor monitor) {
    SubMonitor subProgressMonitor = SubMonitor.convert(monitor, "", 100);
    subProgressMonitor.beginTask("", 100);
    subProgressMonitor.setTaskName("Reset");
    new CallLibBootromWorker(this.frameSetting, this.burner, subProgressMonitor);
    LibBootromByJNA.instance.RegisterPrint(CallLibBootromWorker.callback);
    LibBootromByJNA.instance.RegisterCancel(CallLibBootromWorker.callbackCancel);
    CallLibBootromWorker.setChipType(FastbootView.getDepartmentNumber(this.burner), 
        FastbootView.getChipType(this.burner));
    if (!openSerial())
      return; 
    long comFd = CallLibBootromWorker.getComFd();
    subProgressMonitor.worked(20);
    LocalConfig localConfig = this.burner.getBurnContext().getLocalConfig();
    byte[] data = FileUtils.readAllBytes(localConfig.getLoaderPath());
    long loaderAddress = 0L;
    UnknownDevice setting = getUnkownDevice();
    if (setting != null)
      loaderAddress = setting.getLoaderBurnAdderss(); 
    if (!CallLibBootromWorker.bootromBootDownloadEX(comFd, data, data.length, loaderAddress)) {
      receivedln("Burn Loader Fail");
      printErrorLog("reset");
      return;
    } 
    receivedln("Boot Download Successful");
    subProgressMonitor.worked(60);
    if (!CallLibBootromWorker.sendReset(comFd)) {
      receivedln("Reset Fail");
      printErrorLog("reset");
      return;
    } 
    subProgressMonitor.worked(100);
    receivedln("Reset Successful");
  }
}
